# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jetpack/proto/runtime/v1alpha1/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from jetpack.proto.runtime.v1alpha1 import remote_pb2 as jetpack_dot_proto_dot_runtime_dot_v1alpha1_dot_remote__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='jetpack/proto/runtime/v1alpha1/task.proto',
  package='task',
  syntax='proto3',
  serialized_options=b'\n\010com.taskB\tTaskProtoP\001Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\242\002\003TXX\252\002\004Task\312\002\004Task\342\002\020Task\\GPBMetadata\352\002\004Task',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)jetpack/proto/runtime/v1alpha1/task.proto\x12\x04task\x1a+jetpack/proto/runtime/v1alpha1/remote.proto\"\x93\x04\n\rPersistedTask\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12)\n\x10qualified_symbol\x18\x02 \x01(\tR\x0fqualifiedSymbol\x12!\n\x0c\x65ncoded_args\x18\x03 \x01(\x0cR\x0b\x65ncodedArgs\x12\x1a\n\x08manifest\x18\x04 \x01(\x0cR\x08manifest\x12\x32\n\x06status\x18\x05 \x01(\x0e\x32\x1a.task.PersistedTask.StatusR\x06status\x12&\n\x06result\x18\x06 \x01(\x0b\x32\x0e.remote.ResultR\x06result\x12\x19\n\x08\x61pp_name\x18\x07 \x01(\tR\x07\x61ppName\x12$\n\x0eparent_task_id\x18\x08 \x01(\tR\x0cparentTaskId\x12-\n\x12with_checkpointing\x18\t \x01(\x08R\x11withCheckpointing\x12+\n\x11\x63urrent_iteration\x18\n \x01(\x05R\x10\x63urrentIteration\"\x8e\x01\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07WAITING\x10\x02\x12\t\n\x05READY\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\r\n\tSUCCEEDED\x10\x05\x12\x0e\n\nCANCELLING\x10\x06\x12\r\n\tCANCELLED\x10\x07\x12\x0b\n\x07\x46\x41ILING\x10\x08\x12\n\n\x06\x46\x41ILED\x10\t\"\xaf\x01\n\x11\x43heckpointTracker\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12J\n\x0b\x63heckpoints\x18\x02 \x03(\x0b\x32(.task.CheckpointTracker.CheckpointsEntryR\x0b\x63heckpoints\x1a>\n\x10\x43heckpointsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42y\n\x08\x63om.taskB\tTaskProtoP\x01Z2go.jetpack.io/proto/jetpack/proto/runtime/v1alpha1\xa2\x02\x03TXX\xaa\x02\x04Task\xca\x02\x04Task\xe2\x02\x10Task\\GPBMetadata\xea\x02\x04Taskb\x06proto3'
  ,
  dependencies=[jetpack_dot_proto_dot_runtime_dot_v1alpha1_dot_remote__pb2.DESCRIPTOR,])



_PERSISTEDTASK_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='task.PersistedTask.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAITING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANCELLED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILING', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=486,
  serialized_end=628,
)
_sym_db.RegisterEnumDescriptor(_PERSISTEDTASK_STATUS)


_PERSISTEDTASK = _descriptor.Descriptor(
  name='PersistedTask',
  full_name='task.PersistedTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='task.PersistedTask.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qualified_symbol', full_name='task.PersistedTask.qualified_symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='qualifiedSymbol', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoded_args', full_name='task.PersistedTask.encoded_args', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='encodedArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifest', full_name='task.PersistedTask.manifest', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='manifest', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='task.PersistedTask.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='task.PersistedTask.result', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='result', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='task.PersistedTask.app_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='appName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_task_id', full_name='task.PersistedTask.parent_task_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parentTaskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_checkpointing', full_name='task.PersistedTask.with_checkpointing', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withCheckpointing', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_iteration', full_name='task.PersistedTask.current_iteration', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currentIteration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PERSISTEDTASK_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=628,
)


_CHECKPOINTTRACKER_CHECKPOINTSENTRY = _descriptor.Descriptor(
  name='CheckpointsEntry',
  full_name='task.CheckpointTracker.CheckpointsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='task.CheckpointTracker.CheckpointsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='task.CheckpointTracker.CheckpointsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=806,
)

_CHECKPOINTTRACKER = _descriptor.Descriptor(
  name='CheckpointTracker',
  full_name='task.CheckpointTracker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='task.CheckpointTracker.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoints', full_name='task.CheckpointTracker.checkpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='checkpoints', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHECKPOINTTRACKER_CHECKPOINTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=806,
)

_PERSISTEDTASK.fields_by_name['status'].enum_type = _PERSISTEDTASK_STATUS
_PERSISTEDTASK.fields_by_name['result'].message_type = jetpack_dot_proto_dot_runtime_dot_v1alpha1_dot_remote__pb2._RESULT
_PERSISTEDTASK_STATUS.containing_type = _PERSISTEDTASK
_CHECKPOINTTRACKER_CHECKPOINTSENTRY.containing_type = _CHECKPOINTTRACKER
_CHECKPOINTTRACKER.fields_by_name['checkpoints'].message_type = _CHECKPOINTTRACKER_CHECKPOINTSENTRY
DESCRIPTOR.message_types_by_name['PersistedTask'] = _PERSISTEDTASK
DESCRIPTOR.message_types_by_name['CheckpointTracker'] = _CHECKPOINTTRACKER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PersistedTask = _reflection.GeneratedProtocolMessageType('PersistedTask', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTEDTASK,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.task_pb2'
  # @@protoc_insertion_point(class_scope:task.PersistedTask)
  })
_sym_db.RegisterMessage(PersistedTask)

CheckpointTracker = _reflection.GeneratedProtocolMessageType('CheckpointTracker', (_message.Message,), {

  'CheckpointsEntry' : _reflection.GeneratedProtocolMessageType('CheckpointsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHECKPOINTTRACKER_CHECKPOINTSENTRY,
    '__module__' : 'jetpack.proto.runtime.v1alpha1.task_pb2'
    # @@protoc_insertion_point(class_scope:task.CheckpointTracker.CheckpointsEntry)
    })
  ,
  'DESCRIPTOR' : _CHECKPOINTTRACKER,
  '__module__' : 'jetpack.proto.runtime.v1alpha1.task_pb2'
  # @@protoc_insertion_point(class_scope:task.CheckpointTracker)
  })
_sym_db.RegisterMessage(CheckpointTracker)
_sym_db.RegisterMessage(CheckpointTracker.CheckpointsEntry)


DESCRIPTOR._options = None
_CHECKPOINTTRACKER_CHECKPOINTSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# __version__ is placeholder
# It gets set in the build/publish process (publish_with_credentials.sh)
__version__ = "0.5.1-dev202204281651140536"

api_key = ""
"""[Experimental] api_key enables access to a runtime in a jetpack cluster
Any errors with the value will be raised when a jetroutine executes.
"""

from typing import Dict

from jetpack.cmd import _root
from jetpack.core._interface import function, jet, jetroutine, schedule, workflow

__pdoc__: Dict[str, bool] = {}

# Exclude Internal Submodules
_exclude_list = [
    "cmd",
    "config",
    "proto",
    "runtime",
    "util",
]
for key in _exclude_list:
    __pdoc__[key] = False
# Include core Submodule
__pdoc__["core"] = True

__all__ = ["function", "jet", "jetroutine", "schedule", "workflow", "api_key"]


def run() -> None:
    # options can be passed in as env variables with JETPACK prefix
    # e.g. JETPACK_ENTRYPOINT
    _root.cli(auto_envvar_prefix="JETPACK")
